# USBGuard Simple GUI Py/Qt

A simple unambitious system tray applet and GUI for interacting with
[USBGuard](https://usbguard.github.io/).

It is implemented in Python 3, using 
[Qt for Python / PySide2](https://www.qt.io/qt-for-python) for
graphical interactions, and communicating with USBGuard via
[D-Bus](https://dbus.freedesktop.org/doc/dbus-python/).
